xlrd documentation
==================

xlrd is a library for reading data and formatting information from Excel
files, whether they are .xls or .xlsx files.

.. toctree::
   :maxdepth: 1

   unicode.rst
   dates.rst
   references.rst
   formatting.rst
   on_demand.rst
   vulnerabilities.rst
   api.rst

You may also wish to consult the `tutorial`__.

__ https://github.com/python-excel/tutorial

For details of how to install the package or get involved in its
development, please see the sections below:

.. toctree::
   :maxdepth: 1

   installation.rst
   development.rst
   changes.rst
   acknowledgements.rst
   licenses.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
